﻿using Infragistics.Win.UltraWinGrid;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace UltraGridAddNewCancelDemo
{
    public partial class Form1 : Form
    {
        DataTable table;
        public Form1()
        {
            InitializeComponent();

            Random r = new Random();

            table = new DataTable();
            table.Columns.Add("ID", typeof(int));
            table.Columns.Add("Label", typeof(string));
            table.Columns.Add("Number", typeof(int));

            for (int i = 0; i < 10; i++)
            {
                DataRow row = table.NewRow();
                row[0] = i;
                row[1] = "Item " + i.ToString();
                row[2] = r.Next(1000);
                table.Rows.Add(row);
            }

            ultraGrid1.InitializeLayout += UltraGrid1_InitializeLayout;
            ultraGrid1.BeforeRowUpdate += UltraGrid1_BeforeRowUpdate;            
            ultraGrid1.DataSource = table;                            
        }

        private void UltraGrid1_BeforeRowUpdate(object sender, CancelableRowEventArgs e)
        {
            UltraGridRow gridRow = e.Row;
            DataRowView item = gridRow.ListObject as DataRowView;
            int id = (int)item.Row[0];

            bool cancel = false;

            for(int i=0; i<table.Rows.Count; i++)
            {
                DataRow row = table.Rows[i];
                int tableId = (int)row[0];

                if(tableId == id)
                {
                    cancel = true;
                    break;
                }
            }

            e.Cancel = cancel;            

            if (cancel)
            {
                MessageBox.Show("Cannot have duplicate IDs");

                object[] info = new object[table.Columns.Count];

                for(int i=0; i < info.Length; i++)
                {
                    info[i] = item.Row[i];
                }

                BeginInvoke(new Action(() => UpdateAddNewRow(info)));

                cancel = false;
            }
        }

        public void UpdateAddNewRow(object[] info)
        {
            var x = ultraGrid1.Rows.TemplateAddRow;

            for(int i=0; i<info.Length; i++)
            {
                x.Cells[i].Value = info[i];
            }

            ultraGrid1.ActiveCell = x.Cells[0];
            ultraGrid1.PerformAction(UltraGridAction.EnterEditMode);
            
        }

        private void UltraGrid1_InitializeLayout(object sender, Infragistics.Win.UltraWinGrid.InitializeLayoutEventArgs e)
        {
            UltraGridLayout layout = e.Layout;            
            layout.Override.AllowAddNew = Infragistics.Win.UltraWinGrid.AllowAddNew.FixedAddRowOnTop;            
            
        }
    }

    public class SampleData
    {
        public int ID { get; set; }
        public string Label { get; set; }
        public int Number { get; set; }
    }
}
